==> libreoffice-still-sdk-24.2.7-5-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1MailMerge =
[
    [ "BlindCopiesTo", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ac8f8e5afa143e76b72ee80000d95c37a", null ],
    [ "CopiesTo", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#aa463af48a35ce0c5fc6c341463e29afc", null ],
    [ "PrintOptions", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a1932cbe544fa55feab463f102feb37fd", null ],
    [ "Selection", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a42f93ea78e286c0f30c2ddf14e1b0cb6", null ],
    [ "DataAccessDescriptor", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a4beb8413be504f53359c66a043c1e7a1", null ],
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "XJob", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a5e7de69f5f95d9c98ad8bf5f398c79ca", null ],
    [ "XMailMergeBroadcaster", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a571f0b867cb3230366ef1ddb842ba9fc", null ],
    [ "XCancellable", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#aec2d5a7c38fceefa8b2acb1f7cffe77c", null ],
    [ "ActiveConnection", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a765ecad8eb3c9ef970f0d98ef33b54ca", null ],
    [ "AddressFromColumn", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a74ab75477b89fa501ca98703cac34d65", null ],
    [ "AttachmentFilter", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a48f23061f75536dab8e709b2cf576337", null ],
    [ "AttachmentName", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#adb91f316b1ef67c5880a95ffaf8375ca", null ],
    [ "Command", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a70272cc3797fc39c8a694c651bef53ef", null ],
    [ "CommandType", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a01e54edfb2814946f220267568c3868e", null ],
    [ "DataSourceName", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ae32b88b27240268a6a5a2fecca03e1df", null ],
    [ "DocumentURL", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ae7c616fc9b88d4d54047d1c6e7f82410", null ],
    [ "EscapeProcessing", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#aa71981b851337d3842caede42c842c31", null ],
    [ "FileNameFromColumn", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a7d19d475e7460a0f8fa9745539305bb7", null ],
    [ "FileNamePrefix", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a25a3fdb428b5f11f53e7ae2fbfbb8ab4", null ],
    [ "Filter", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a36e60b26868092e2acd03532c3dc0549", null ],
    [ "InServerPassword", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a56544dbc013f6d5fd0bfaabe7e1ee820", null ],
    [ "MailBody", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ad8d70a7256be76c28df848316c8cec60", null ],
    [ "Model", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a241a91261f54c0cb4bee344b651dc7ee", null ],
    [ "OutputType", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a6c35ff0521b11b3b02526f6dc6524bf1", null ],
    [ "OutputURL", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a700491f62aa161e40e2f919af3b8a540", null ],
    [ "OutServerPassword", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a8558a76fb028d7ebf2cffcd33d81b8da", null ],
    [ "ResultSet", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#add78926cc45ac69caf3a270627874c73", null ],
    [ "SaveAsSingleFile", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a42be470278537ac051d313a5550c9782", null ],
    [ "SaveFilter", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a578f689f33fed08a2688e9f2407f6c1b", null ],
    [ "SendAsAttachment", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a958aca0d21dda4bf3ca3826d67af7b25", null ],
    [ "SendAsHTML", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a51656deda7cd157ed9aa8fa9758e2989", null ],
    [ "SinglePrintJobs", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a7b2a648aab878eaafd2b57d3313fed9c", null ],
    [ "Subject", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a00533685efc8eefd6feeae97dd0cc491", null ]
];

==> libreoffice-still-sdk-25.2.7-5-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1MailMerge =
[
    [ "BlindCopiesTo", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ac8f8e5afa143e76b72ee80000d95c37a", null ],
    [ "CopiesTo", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#aa463af48a35ce0c5fc6c341463e29afc", null ],
    [ "PrintOptions", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a1932cbe544fa55feab463f102feb37fd", null ],
    [ "Selection", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a42f93ea78e286c0f30c2ddf14e1b0cb6", null ],
    [ "com::sun::star::sdb::DataAccessDescriptor", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a4beb8413be504f53359c66a043c1e7a1", null ],
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "com::sun::star::task::XJob", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a5e7de69f5f95d9c98ad8bf5f398c79ca", null ],
    [ "com::sun::star::text::XMailMergeBroadcaster", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a571f0b867cb3230366ef1ddb842ba9fc", null ],
    [ "com::sun::star::util::XCancellable", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#aec2d5a7c38fceefa8b2acb1f7cffe77c", null ],
    [ "ActiveConnection", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a765ecad8eb3c9ef970f0d98ef33b54ca", null ],
    [ "AddressFromColumn", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a74ab75477b89fa501ca98703cac34d65", null ],
    [ "AttachmentFilter", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a48f23061f75536dab8e709b2cf576337", null ],
    [ "AttachmentName", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#adb91f316b1ef67c5880a95ffaf8375ca", null ],
    [ "Command", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a70272cc3797fc39c8a694c651bef53ef", null ],
    [ "CommandType", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a01e54edfb2814946f220267568c3868e", null ],
    [ "DataSourceName", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ae32b88b27240268a6a5a2fecca03e1df", null ],
    [ "DocumentURL", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ae7c616fc9b88d4d54047d1c6e7f82410", null ],
    [ "EscapeProcessing", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#aa71981b851337d3842caede42c842c31", null ],
    [ "FileNameFromColumn", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a7d19d475e7460a0f8fa9745539305bb7", null ],
    [ "FileNamePrefix", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a25a3fdb428b5f11f53e7ae2fbfbb8ab4", null ],
    [ "Filter", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a36e60b26868092e2acd03532c3dc0549", null ],
    [ "InServerPassword", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a56544dbc013f6d5fd0bfaabe7e1ee820", null ],
    [ "MailBody", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#ad8d70a7256be76c28df848316c8cec60", null ],
    [ "Model", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a241a91261f54c0cb4bee344b651dc7ee", null ],
    [ "OutputType", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a6c35ff0521b11b3b02526f6dc6524bf1", null ],
    [ "OutputURL", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a700491f62aa161e40e2f919af3b8a540", null ],
    [ "OutServerPassword", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a8558a76fb028d7ebf2cffcd33d81b8da", null ],
    [ "ResultSet", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#add78926cc45ac69caf3a270627874c73", null ],
    [ "SaveAsSingleFile", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a42be470278537ac051d313a5550c9782", null ],
    [ "SaveFilter", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a578f689f33fed08a2688e9f2407f6c1b", null ],
    [ "SendAsAttachment", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a958aca0d21dda4bf3ca3826d67af7b25", null ],
    [ "SendAsHTML", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a51656deda7cd157ed9aa8fa9758e2989", null ],
    [ "SinglePrintJobs", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a7b2a648aab878eaafd2b57d3313fed9c", null ],
    [ "Subject", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a00533685efc8eefd6feeae97dd0cc491", null ]
];
